@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003 Imendio HB
+ * Copyright (C) 2003 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,7 +22,7 @@
 #define __GOSSIP_REGISTER_H__
 
 #include <gtk/gtkwindow.h>
-#include "gossip-account.h"
+#include <libgossip/gossip-account.h>
 
 gboolean gossip_register_account (GossipAccount *account,
 				  GtkWindow     *parent);
